@@ -1,20 +1,16 @@
-from alembic.testing.requirements import SuiteRequirements
-from alembic.testing import exclusions
 from alembic import util
+from alembic.testing import exclusions
+from alembic.testing.requirements import SuiteRequirements
 from alembic.util import sqla_compat
 
 
 class DefaultRequirements(SuiteRequirements):
-
     @property
     def schemas(self):
         """Target database must support external schemas, and have one
         named 'test_schema'."""
 
-        return exclusions.skip_if([
-            "sqlite",
-            "firebird"
-        ], "no schema support")
+        return exclusions.skip_if(["sqlite", "firebird"], "no schema support")
 
     @property
     def no_referential_integrity(self):
@@ -48,12 +44,12 @@ class DefaultRequirements(SuiteRequirements):
     @property
     def unnamed_constraints(self):
         """constraints without names are supported."""
-        return exclusions.only_on(['sqlite'])
+        return exclusions.only_on(["sqlite"])
 
     @property
     def fk_names(self):
         """foreign key constraints always have names in the DB"""
-        return exclusions.fails_on('sqlite')
+        return exclusions.fails_on("sqlite")
 
     @property
     def no_name_normalize(self):
@@ -63,20 +59,24 @@ class DefaultRequirements(SuiteRequirements):
 
     @property
     def reflects_fk_options(self):
-        return exclusions.only_on([
-            'postgresql', 'mysql',
-            lambda config: util.sqla_110 and
-            exclusions.against(config, 'sqlite')])
+        return exclusions.only_on(
+            [
+                "postgresql",
+                "mysql",
+                lambda config: util.sqla_110
+                and exclusions.against(config, "sqlite"),
+            ]
+        )
 
     @property
     def fk_initially(self):
         """backend supports INITIALLY option in foreign keys"""
-        return exclusions.only_on(['postgresql'])
+        return exclusions.only_on(["postgresql"])
 
     @property
     def fk_deferrable(self):
         """backend supports DEFERRABLE option in foreign keys"""
-        return exclusions.only_on(['postgresql'])
+        return exclusions.only_on(["postgresql"])
 
     @property
     def flexible_fk_cascades(self):
@@ -84,8 +84,7 @@ class DefaultRequirements(SuiteRequirements):
         full range of keywords (e.g. NO ACTION, etc.)"""
 
         return exclusions.skip_if(
-            ['oracle'],
-            'target backend has poor FK cascade syntax'
+            ["oracle"], "target backend has poor FK cascade syntax"
         )
 
     @property
@@ -97,10 +96,13 @@ class DefaultRequirements(SuiteRequirements):
         """Target driver reflects the name of primary key constraints."""
 
         return exclusions.fails_on_everything_except(
-            'postgresql', 'oracle', 'mssql', 'sybase',
+            "postgresql",
+            "oracle",
+            "mssql",
+            "sybase",
             lambda config: (
                 util.sqla_110 and exclusions.against(config, "sqlite")
-            )
+            ),
         )
 
     @property
@@ -122,8 +124,10 @@ class DefaultRequirements(SuiteRequirements):
                 return False
             count = config.db.scalar(
                 "SELECT count(*) FROM pg_extension "
-                "WHERE extname='%s'" % name)
+                "WHERE extname='%s'" % name
+            )
             return bool(count)
+
         return exclusions.only_if(check, "needs %s extension" % name)
 
     @property
@@ -134,7 +138,6 @@ class DefaultRequirements(SuiteRequirements):
     def btree_gist(self):
         return self._has_pg_extension("btree_gist")
 
-
     @property
     def autoincrement_on_composite_pk(self):
         return exclusions.skip_if(["sqlite"], "not supported by database")
@@ -153,34 +156,42 @@ class DefaultRequirements(SuiteRequirements):
     @property
     def mysql_check_reflection_or_none(self):
         def go(config):
-            return not self._mariadb_102(config) \
-                or self.sqlalchemy_1115.enabled
+            return (
+                not self._mariadb_102(config) or self.sqlalchemy_1115.enabled
+            )
+
         return exclusions.succeeds_if(go)
 
     @property
     def mysql_timestamp_reflection(self):
         def go(config):
-            return not self._mariadb_102(config) \
-                or self.sqlalchemy_1115.enabled
+            return (
+                not self._mariadb_102(config) or self.sqlalchemy_1115.enabled
+            )
+
         return exclusions.only_if(go)
 
     def _mariadb_102(self, config):
-        return exclusions.against(config, "mysql") and \
-            sqla_compat._is_mariadb(config.db.dialect) and \
-            sqla_compat._mariadb_normalized_version_info(
-                config.db.dialect) > (10, 2)
+        return (
+            exclusions.against(config, "mysql")
+            and sqla_compat._is_mariadb(config.db.dialect)
+            and sqla_compat._mariadb_normalized_version_info(config.db.dialect)
+            > (10, 2)
+        )
 
     def _mariadb_only_102(self, config):
-        return exclusions.against(config, "mysql") and \
-            sqla_compat._is_mariadb(config.db.dialect) and \
-            sqla_compat._mariadb_normalized_version_info(
-                config.db.dialect) >= (10, 2) and \
-            sqla_compat._mariadb_normalized_version_info(
-                config.db.dialect) < (10, 3)
+        return (
+            exclusions.against(config, "mysql")
+            and sqla_compat._is_mariadb(config.db.dialect)
+            and sqla_compat._mariadb_normalized_version_info(config.db.dialect)
+            >= (10, 2)
+            and sqla_compat._mariadb_normalized_version_info(config.db.dialect)
+            < (10, 3)
+        )
 
     def _mysql_not_mariadb_102(self, config):
         return exclusions.against(config, "mysql") and (
-            not sqla_compat._is_mariadb(config.db.dialect) or
-            sqla_compat._mariadb_normalized_version_info(
-                config.db.dialect) < (10, 2)
+            not sqla_compat._is_mariadb(config.db.dialect)
+            or sqla_compat._mariadb_normalized_version_info(config.db.dialect)
+            < (10, 2)
         )
